==> open-xchange-templating_6.14.0.0.orig.tar.gz: open-xchange-templating-6.14.0.0/src/com/openexchange/templating/impl/DocumentMetadataMatcher.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.templating.impl;

import com.openexchange.groupware.infostore.DocumentMetadata;


/**
 * {@link DocumentMetadataMatcher}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class DocumentMetadataMatcher {
    private DocumentMetadata bestMatch;
    private String name;
    private int score;

    public DocumentMetadataMatcher(String name) {
        this.name = name;
        this.score = 0;
        
    }
    
    public boolean hasPerfectMatch() {
        return score > 10;
    }

    public DocumentMetadata getBestMatch() {
        return bestMatch;
    }
    
    public void propose(DocumentMetadata document) {
        int newScore = 0;
        String fileName = document.getFileName();
        if(fileName.equals(name)) {
            newScore = 100;
        }
        if(fileName.contains(".")) {
            String filenameWithoutExtension = fileName.substring(0, fileName.lastIndexOf('.'));
            if(filenameWithoutExtension.equals(name)) {
                newScore = 5;
            }
        }
        
        if(document.getTitle().equals(name)) {
            newScore = 7;
        }
        
        
        if(newScore > score) {
            score = newScore;
            bestMatch = document;
        }
    }
}

==> open-xchange-templating_6.20.8.0.orig.tar.gz: open-xchange-templating-6.20.8.0/src/com/openexchange/templating/impl/DocumentMetadataMatcher.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.templating.impl;

import com.openexchange.groupware.infostore.DocumentMetadata;


/**
 * {@link DocumentMetadataMatcher}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class DocumentMetadataMatcher {
    private DocumentMetadata bestMatch;
    private final String name;
    private int score;

    public DocumentMetadataMatcher(final String name) {
        this.name = name;
        this.score = 0;
        
    }
    
    public boolean hasPerfectMatch() {
        return score > 10;
    }

    public DocumentMetadata getBestMatch() {
        return bestMatch;
    }
    
    public void propose(final DocumentMetadata document) {
        int newScore = 0;
        final String fileName = document.getFileName();
        if (fileName == null) {
        	return;
        }
        if (fileName.equals(name)) {
            newScore = 100;
        }
        if(fileName.contains(".")) {
            final String filenameWithoutExtension = fileName.substring(0, fileName.lastIndexOf('.'));
            if(filenameWithoutExtension.equals(name)) {
                newScore = 5;
            }
        }
        
        if(document.getTitle().equals(name)) {
            newScore = 7;
        }
        
        
        if(newScore > score) {
            score = newScore;
            bestMatch = document;
        }
    }
}
